// Copyright 2011 Thomas Kamps anubis1@linux-ecke.de
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#include "webview.h"

#include <QAction>
#include <QDebug>
#include "dialogs/passworddialog.h"

QNetworkAccessManager* WebView::manager = 0;

WebView::WebView(QWidget *parent) : QWebView(parent) {
	curHoverUrl = QString();

	//Translate page-actions and give them icons from Lightweight2
	page()->action(QWebPage::Stop)->setIcon(QIcon(":/icons/stop.png"));
	page()->action(QWebPage::Back)->setText(tr("Go back"));
	page()->action(QWebPage::Back)->setIcon(QIcon(":/icons/back.png"));

	page()->action(QWebPage::Reload)->setText(tr("Reload"));
	page()->action(QWebPage::Reload)->setIcon(QIcon(":/icons/reload.png"));

	page()->action(QWebPage::OpenLink)->setText(tr("Open link"));
	page()->action(QWebPage::OpenLinkInNewWindow)->setText(tr("Open link in new tab"));
	page()->action(QWebPage::OpenLinkInNewWindow)->setIcon(QIcon(":/icons/new.png"));

	page()->action(QWebPage::DownloadLinkToDisk)->setText(tr("Download link"));
	page()->action(QWebPage::DownloadLinkToDisk)->setIcon(QIcon(":/icons/download_run.png"));
	page()->action(QWebPage::CopyLinkToClipboard)->setText(tr("Copy link"));

	page()->setNetworkAccessManager(manager);

	connect(page(), SIGNAL(linkHovered(QString,QString,QString)), this, SLOT(updateCurHoverUrl(QString)));
	connect(page()->networkAccessManager(), SIGNAL(authenticationRequired(QNetworkReply*,QAuthenticator*)), this, SLOT(getAuthentication(QNetworkReply*, QAuthenticator*)));
}

QWebView* WebView::createWindow(QWebPage::WebWindowType type) {
	Q_UNUSED(type);

	QWebView* view;
	emit(newWindow(&view));
	return view;
}

void WebView::mousePressEvent(QMouseEvent *e) {
	if (e->button() == Qt::MidButton) {
		if (curHoverUrl.isNull()) return;
		QWebView* view = createWindow(QWebPage::WebBrowserWindow);
		view->load(QUrl(curHoverUrl));
	}
	else QWebView::mousePressEvent(e);
}

void WebView::updateCurHoverUrl(QString url) {
	curHoverUrl = url;
}

void WebView::getAuthentication(QNetworkReply* repl, QAuthenticator *auth) {
	Q_UNUSED(repl);

	PasswordDialog d(auth, 0);
	d.exec();
}
